/////////////////////////////////////////////////////////////////////////////
// Ac97.h : SBLive! Codec Class Header File
// <THIS IS OPEN SOURCE CODE>
//
// v2.0 (01/07/2000)
// C++ Version
//
// <uses system file EMUAPS.VXD>
//
// History
// -------
//
// Date         Author          Description
// ----         ------          -----------
// 01/07/2000   Music Master    Initial VXD Version
//

#ifndef AC97
#define AC97

#include "Windows.h"
#include "8010.h"

// misc
#define	MAX_OUT_VOLUME	63
#define	MAX_IN_GAIN		15
#define	INT_ERROR		-1

#define TIMEOUT_ERROR_TEXT  "FATAL: Timeout error in function Sblive_writeac97"
#define DEBUG_FILE          "\\ac97_debug.txt"

// vxd
#define EMU_VXD				"\\\\.\\EMUAPS.VXD"
#define EMU_CONTROL_CODE	0x13
#define	VXD_WRITE			0x06
#define	VXD_READ			0x05
#define	VXD_BYTE_DATA		0x00
#define	VXD_WORD_DATA		0x01
#define	VXD_LONG_DATA		0x02
#define VXD_MAX_TIMEOUT     16

// library version ask defines
#define LIBVER_MINOR	1
#define LIBVER_MAJOR	2

// input enum gain types
enum gain
{
	SOURCE_MIC,
	SOURCE_CD,
	SOURCE_VIDEO,
	SOURCE_LINE1,
	SOURCE_LINE,
	SOURCE_VOLUME,
	SOURCE_OGAIN,	// Used to be PHONEOUT 
	SOURCE_PHONEIN,	
	SOURCE_TREBLE,
	SOURCE_BASS,
	SOURCE_END
};

// output enum types
enum dest
{
	DEST_MASTER,
	DEST_HEADPHONE,
	DEST_MASTERMONO,
	DEST_MASTERTONE,
	DEST_SPEAKER,
	DEST_PHONE,
	DEST_MIC,
	DEST_LINE,
	DEST_CD,
	DEST_VIDEO,
	DEST_AUX,
	DEST_PCM,
	DEST_END
};


// Ac97 codec class (static object)
class Ac97
{
public:
	// get the library version
	static int  GetLibVersion( int part );

	// get the SB/EMU device handle (via the VXD)
	static bool	DetectSBLive( void );

    // find out status of the handler
    static bool Status( void );

	// enable the codec and reset the mixer to defaults
	static bool Reset( void );

	static bool SetRecordSource( int src );
	static int  GetRecordSource( void );

	static bool SetRecordGain( int gain );
	static int	GetRecordGain( void );

	static bool SetVolumeOut( int dest, int vol );

    // delete trace file
	static bool	TraceClear( void );

private:

	// AC97 mixer access functions (port access)
	static bool Sblive_readac97( char index, short *pdata );
	static bool Sblive_writeac97( char index, short data );
	static bool Sblive_rmwac97( char index, short data, short mask );

	static bool	Vxd_Write( int reg, int sizeID, long value );
	static bool	Vxd_Read( int reg, int sizeID, void *valueptr );

    // misc
	static bool	Trace( char * pString );

	// object variables
	static HANDLE	 m_Sb_hw;	// device handle
	static const int m_Version;	// object version
};

#endif

// Ac97.h : SBLive! Codec Class Header File
/////////////////////////////////////////////////////////////////////////////

